summaryrefslogtreecommitdiffstats
path: root/smb4k/listview/smb4kshareslistview.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/listview/smb4kshareslistview.h')
-rw-r--r--smb4k/listview/smb4kshareslistview.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/smb4k/listview/smb4kshareslistview.h b/smb4k/listview/smb4kshareslistview.h
index df1c265..ecd1d11 100644
--- a/smb4k/listview/smb4kshareslistview.h
+++ b/smb4k/listview/smb4kshareslistview.h
@@ -46,16 +46,17 @@ class Smb4KSharesListViewToolTip;
class Smb4KSharesListView : public KListView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor
*
* @param parent The parent widget
*
* @param name The name of this object
*/
- Smb4KSharesListView( QWidget *parent = 0, const char *name = 0 );
+ Smb4KSharesListView( TQWidget *tqparent = 0, const char *name = 0 );
/**
* The destructor
@@ -92,7 +93,7 @@ class Smb4KSharesListView : public KListView
protected:
/**
* Reimplemented (sort of) from QListView to enable dragging. As QDragObject
* a KURLDrag will be returned.
*
* @returns a KURLDrag object.
@@ -100,41 +101,41 @@ class Smb4KSharesListView : public KListView
KURLDrag *dragObject();
/**
* Reimplemented from QListView to allow some actions to be carried
* out before the drag begins.
*/
void startDrag();
/**
* Reimplemented from QListView.
*/
- void contentsDragEnterEvent( QDragEnterEvent * );
+ void contentsDragEnterEvent( TQDragEnterEvent * );
/**
* Reimplemented from QListView.
*/
- void contentsDragMoveEvent( QDragMoveEvent *e );
+ void contentsDragMoveEvent( TQDragMoveEvent *e );
/**
* Reimplemented from QListView.
*/
- void contentsDropEvent( QDropEvent *e );
+ void contentsDropEvent( TQDropEvent *e );
/**
* Reimplemented from QListView. This function is used to
* show the tooltips.
*/
- void contentsMouseMoveEvent( QMouseEvent *e );
+ void contentsMouseMoveEvent( TQMouseEvent *e );
protected slots:
/**
* This slot is connected to KListView::pressed() and clears the selection
* if the user clicked on the viewport.
*
- * @param item The QIconViewItem that the user clicked or NULL
+ * @param item The TQIconViewItem that the user clicked or NULL
* if he/she pressed a mouse button on the viewport.
*/
- void slotPressed( QListViewItem *item );
+ void slotPressed( TQListViewItem *item );
/**
* This slot shows the tool tip for an icon view item.
@@ -145,7 +146,7 @@ class Smb4KSharesListView : public KListView
/**
* The current global mouse position
*/
- QPoint m_pos;
+ TQPoint m_pos;
/**
* The tool tip
@@ -46,16 +46,17 @@ class Smb4KSharesListViewToolTip;
* The constructor
*
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
*
* @param name The name of this object
@@ -92,7 +93,7 @@ class Smb4KSharesListView : public KListView
protected:
/**
- * Reimplemented (sort of) from QListView to enable dragging. As QDragObject
+ * Reimplemented (sort of) from TQListView to enable dragging. As TQDragObject
* a KURLDrag will be returned.
*
@@ -100,41 +101,41 @@ class Smb4KSharesListView : public KListView
KURLDrag *dragObject();
/**
- * Reimplemented from QListView to allow some actions to be carried
+ * Reimplemented from TQListView to allow some actions to be carried
* out before the drag begins.
*/
@@ -100,41 +101,41 @@ class Smb4KSharesListView : public KListView
void startDrag();
/**
- * Reimplemented from QListView.
+ * Reimplemented from TQListView.
*/
@@ -100,41 +101,41 @@ class Smb4KSharesListView : public KListView
/**
- * Reimplemented from QListView.
+ * Reimplemented from TQListView.
*/
@@ -100,41 +101,41 @@ class Smb4KSharesListView : public KListView
/**
- * Reimplemented from QListView.
+ * Reimplemented from TQListView.
*/
@@ -100,41 +101,41 @@ class Smb4KSharesListView : public KListView
/**
- * Reimplemented from QListView. This function is used to
+ * Reimplemented from TQListView. This function is used to
* show the tooltips.
*/